@@ -184,13 +184,14 @@ class BaseIdentifier(CbcMixin, BaseElement, ABC):
 
     def _handle_peppol_id(self) -> None:
         """
-        Handle PEPPOL participant ID - apply normalization.
+        Handle PEPPOL participant ID - apply normalization and validation.
 
         Logic:
         1. Look up scheme in PEPPOL registry
         2. Extract value using scheme regex if defined
-        3. Lowercase value if schemeID is ISO6523 numeric code
-        4. Auto-populate schemeName from scheme.name
+        3. If extraction fails (doesn't match regex), clear schemeID to prevent invalid output
+        4. Lowercase value if schemeID is ISO6523 numeric code
+        5. Auto-populate schemeName from scheme.name
         """
         from ..identifiers import get_scheme
 
@@ -204,7 +205,12 @@ class BaseIdentifier(CbcMixin, BaseElement, ABC):
             extracted = scheme.extract_value(self.value)
             if extracted:
                 self.value = extracted
-            # If extraction fails, keep original value
+            else:
+                # Extraction failed - value doesn't match regex pattern
+                # Clear schemeID to prevent generating invalid schemeID attribute in XML
+                self.schemeID = None
+                self.schemeName = None
+                return
 
         # Step 2: Lowercase if ISO6523 code
         if self.schemeID.isdigit():
